torch-max-mem |release| Documentation
=====================================

``torch-max-mem`` is a package to enable automatic memory optimization / batch size selection via simple function
decorators.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation
   usage

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
